@@ -122,7 +122,7 @@ QVariant TalkerListModel::headerData(int section, Qt::Orientation orientation, i
         case 2: return i18n("Synthesizer");
         case 3: return i18n("Voice Code");
         case 4: return i18n("Gender");
-        case 5: return i18n("Volume");
+        case 5: return i18nc("Volume of noise", "Volume");
         case 6: return i18n("Rate");
     };
 
