@@ -1,7 +1,7 @@
 /******************************************************************************
     Main speaking functions for the FreeTTS Plug in
     -------------------
-    Copyright : (C) 2004 Paul Giannaros
+    Copyright : (C) 2004 Paul Giannaros <ceruleanblaze@gmail.com>
     -------------------
     Original author: Paul Giannaros <ceruleanblaze@gmail.com>
     Current Maintainer: Paul Giannaros <ceruleanblaze@gmail.com>
@@ -11,14 +11,16 @@
  *                                                                             *
  *     This program is free software; you can redistribute it and/or modify    *
  *     it under the terms of the GNU General Public License as published by    *
- *     the Free Software Foundation; version 2 of the License.                 *
+ *     the Free Software Foundation; version 2 of the License or               *
+ *     (at your option) version 3.                                             *
  *                                                                             *
  ******************************************************************************/
 
-#ifndef _FREETTSPROC_H_
-#define _FREETTSPROC_H_
+#ifndef FREETTSPROC_H
+#define FREETTSPROC_H
 
 #include <QtCore/QMutex>
+#include <QtCore/QStringList>
 
 #include <pluginproc.h>
 
@@ -173,5 +175,5 @@ private:
     bool m_waitingStop;
 };
 
-#endif // _FREETTSPROC_H_
+#endif // FREETTSPROC_H
 
